# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['fringes']

package_data = \
{'': ['*']}

install_requires = \
['argparse>=1.4.0,<2.0.0',
 'asdf>=2.14.3,<3.0.0',
 'numba>=0.57.1,<0.58.0',
 'numpy>=1.23.5,<2.0.0',
 'opencv-contrib-python>=4.7.0,<5.0.0',
 'pyyaml>=6.0,<7.0',
 'scikit-image>=0.21.0,<0.22.0',
 'scipy>=1.10.0,<2.0.0',
 'si-prefix>=1.2.2,<2.0.0',
 'sympy>=1.11.1,<2.0.0',
 'toml>=0.10.2,<0.11.0']

setup_kwargs = {
    'name': 'fringes',
    'version': '0.2.1',
    'description': 'Phase shifting algorithms for encoding and decoding sinusoidal fringe patterns.',
    'long_description': "# Fringes\n![PyPI](https://img.shields.io/pypi/v/fringes)\n![GitHub top language](https://img.shields.io/github/languages/top/comimag/fringes)\n![Read the Docs](https://img.shields.io/readthedocs/fringes)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n![PyPI - License](https://img.shields.io/pypi/l/fringes)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/fringes)\n\n<!---\n![GitHub](https://img.shields.io/github/license/comimag/fringes)\n--->\n\n<!---\nlink to  paper, please cite\n--->\n\nEasy to use tool for generating and analyzing fringe patterns with phase shifting algorithms.\n\n![Coding Scheme](https://raw.githubusercontent.com/comimag/fringes/main/docs/getting-started/coding-scheme.gif)\\\nPhase Shift Coding Scheme.\n\n## Installation\nYou can install `fringes` directly from [PyPi](https://pypi.org/) via `pip`:\n\n```\npip install fringes\n```\n\n## Usage\nYou instantiate, parameterize and deploy the `Fringes` class:\n\n```python\nimport fringes as frng  # import module\n\nf = frng.Fringes()      # instantiate class\n\nf.glossary              # get glossary\nf.X = 1920              # set width of the fringe patterns\nf.Y = 1080              # set height of the fringe patterns\nf.K = 2                 # set number of sets\nf.N = 4                 # set number of shifts\nf.v = [9, 10]           # set spatial frequencies\nf.T                     # get number of frames\n                            \nI = f.encode()          # encode fringe patterns\nA, B, x = f.decode(I)   # decode fringe patterns\n```\n\nAll parameters are accesible by the respective attributes of the `Fringes` instance\n(a glossary of them is obtained by the attribute `glossary`).\nThey are implemented as class properties (managed attributes).\nNote that some attributes have subdependencies, hence dependent attributes might change as well.\nCircular dependencies are resolved automatically.\n\nFor generating the fringe pattern sequence `I`, use the method `encode()`.\\\nIt returns a [NumPy array](https://numpy.org/doc/stable/reference/generated/numpy.ndarray.html) \nin videoshape (frames `T`, width `X`, height `Y`, color channels `C`).\n\nFor analyzing (recorded) fringe patterns, use the method `decode()`.\\\nIt returns the Numpy arrays brightness `A`, modulation `B` and coordinate `x`.\n\n## Graphical User Interface\nDo you need a GUI? `Fringes` has a sister project which is called `Fringes-GUI`: https://pypi.org/project/fringes-gui/\n\n## Troubleshooting\n<!---\n- __`poetry install` does not work__  \n  First, ensure that poetry is installed correctly as descibed on the [Poetry Website](https://python-poetry.org/docs/).\\\n  Secondly, ensure the correct python version is installed on your system, as specified in the file `pyproject.toml`!\\\n  Thirdly, this can be caused by a proxy which `pip` does not handle correctly.\n  Manually setting the proxy in the Windows settings\n  or even adding a system variable `https_proxy = http://YOUR_PROXY:PORT` can resolve this.\n--->\n\n- __Decoding takes a long time__  \n  This is most likely due to the just-in-time compiler [Numba](https://numba.pydata.org/), \n  which is used for this computationally expensive :\n  During the first execution, an initial compilation is executed. \n  This can take several tens of seconds up to single digit minutes, depending on your CPU.\n  However, for any subsequent execution, the compiled code is cached and the code of the function runs much faster, \n  approaching the speeds of code written in C.\n\n<!---\n- __My decoded coordinates show lots of noise__\n  - Make sure the exposure of your camera is adjusted so that the fringe patterns show up with maximum contrast.\n    Try to avoid under- and overexposure during acquisition.\n  - Try using more, sets `K` and/or shifts `N`.\n  - Adjust the used wavelengths `l` resp. number of periods `v` to ensure the unamboguous measurement range\n    is larger than the pattern length, i.e. <code>UMR &ge; L</code>.\n  - If the decoded modulation is much lower than the decoded brightness,\n    try to use larger wavelengths `l` resp. smaller number of periods `v`.\\\n    If the decoded modulation remains low even with very large wavelengths (less than five periods per screen length),\n    and you are conducting a deflectometric mesurement, the surface under test is probably too rough.\n    Since deflectometry is for specular and glossy surfaces only, it isn't suited for scattering ones.\n    You should consider a different measurement technique, e.g. fringe projection.\n\n- __My decoded coordinates show systematic offsets__\n  - First, ensure that the correct frames were captured while acquiring the fringe pattern sequence.\n    If the timings are not set correctly, the sequence may be a frame off.\n  - Secondly, this might occur if either the camera or the display used have a gamma value very different from 1.\n    - Typically, screens have a gamma value of 2.2; therefore compensate by setting the inverse value\n      <code>gamma<sup>-1</sup> = 1 / 2.2 &approx; 0.45</code> to the `gamma` attribute of the `Fringes` instance.\\\n      Alternatively, change the gamma value of the light source or camera directly.\n    - You can use the static method `gamma_auto_correct` to\n      automatically estimate and apply the gamma correction factor to linearize the display/camera response curve.\n    - You might also use more shifts `N` to compensate for the dominant harmonics of the gamma-nonlinearities.\n--->\n\n## License\nCreative Commons Attribution-NonCommercial-ShareAlike 4.0 International Public License\n\n## Project Status\nThis package is under active development, so features and functionally will be added in the future.\nFeature requests are warmly welcomed!\n",
    'author': 'Christian Kludt',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/comimag/fringes',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<3.13',
}


setup(**setup_kwargs)
